--[[
    Core.lua
    
    Core file for CombatDnd
    
    Author: Borlox
]]--

CombatDnd = AceLibrary("AceAddon-2.0"):new("AceConsole-2.0", "AceEvent-2.0", "AceDB-2.0")

local Waterfall = AceLibrary("Waterfall-1.0")

------

CombatDnd.Options = {
  type = "group",
  args = {
    text = {
      type  = "text",
      name  = "Text",
      desc  = "Change your dnd text.",
      usage = "<text>",
      get   = "GetText",
      set   = "SetText",
    },
    config  = {
      type  = "execute",
      desc  = "Open the config menu. (needs Waterfall-1.0)",
      name  = "Config",
      func  = "Config",
      enabled = "HasWaterfall",
    }
  },
}

CombatDnd:RegisterDB("CombatDndDB", "CombatDndDBPC")
CombatDnd:RegisterDefaults("profile", {
  text = "I'm in combat at the moment. Please try again later.",
})

------

function CombatDnd:OnInitialize()
  self:RegisterChatCommand({"/combatdnd", "/cdnd"}, self.Options)
  
  Waterfall:Register(self.name,
    "title", "CombatDnd Configuration",
    "aceOptions", self.Options,
    "colorR", 1,
    "colorG", 0.2,
    "colorB", 0.2)
end

function CombatDnd:OnEnable()
  self:RegisterEvent("PLAYER_REGEN_DISABLED")
  self:RegisterEvent("PLAYER_REGEN_ENABLED")
end

function CombatDnd:OnDisable()
  self:UnregisterAllEvents()
end

------

function CombatDnd:PLAYER_REGEN_DISABLED()
  if not UnitIsDND("player") then
    SendChatMessage(self.db.profile.text, "DND")
  else
    self.ChangeDnd = nil
  end
end

function CombatDnd:PLAYER_REGEN_ENABLED()
  if UnitIsDND("player") and self.ChangeDnd then
    SendChatMessage("", "DND")
  end
  self.ChangeDnd = 1
end

------

function CombatDnd:GetText()
  return self.db.profile.text
end

function CombatDnd:SetText(new)
  if (new == "") or (new == "DEFAULT") then
    new = "I'm in combat at the moment. Please try again later."
  end
  
  self.db.profile.text = new
end

function CombatDnd:Config()
  Waterfall:Open(self.name)
end